[java-oidc-common] branch main updated: JCOMOIDC-112 - Profile configuration settings for OAuth2 DPoP

Henri Mikkonen henri.mikkonen at iki.fi
Fri May 24 14:23:10 UTC 2024


This is an automated email from the git hooks/post-receive script.

hjmikkon pushed a commit to branch main
in repository java-oidc-common.

View the commit online:
http://git.shibboleth.net/view/?p=java-oidc-common.git;a=commit;h=63c4a62429ade0c8a8c0b4c97996a13c40c09d40

The following commit(s) were added to refs/heads/main by this push:
     new 63c4a62  JCOMOIDC-112 - Profile configuration settings for OAuth2 DPoP
63c4a62 is described below

commit 63c4a62429ade0c8a8c0b4c97996a13c40c09d40
Author: Henri Mikkonen <henri.mikkonen at iki.fi>
AuthorDate: Fri May 24 17:22:50 2024 +0300

    JCOMOIDC-112 - Profile configuration settings for OAuth2 DPoP
    
    https://shibboleth.atlassian.net/browse/JCOMOIDC-112
---
 .../java/net/shibboleth/oidc/profile/core/OidcEventIds.java   | 11 +++++++++--
 1 file changed, 9 insertions(+), 2 deletions(-)

diff --git a/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OidcEventIds.java b/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OidcEventIds.java
index a33fb4c..64a73c4 100644
--- a/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OidcEventIds.java
+++ b/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OidcEventIds.java
@@ -121,10 +121,17 @@ public final class OidcEventIds {
     @Nonnull @NotEmpty public static final String INVALID_TOKEN = "InvalidToken";
     
     /**
      * The id_token is invalid.
      */
     @Nonnull @NotEmpty public static final String INVALID_ACCESS_TOKEN = "InvalidAcessToken";
-    
+
+    /**
+     * The DPoP access token is invalid.
+     * 
+     * @since 3.2.0
+     */
+    @Nonnull @NotEmpty public static final String INVALID_DPOP_ACCESS_TOKEN = "InvalidDPoPAccessToken";
+
     /**
      * The UserInfo claims are invalid.
      */
@@ -121,10 +121,17 @@ public final class OidcEventIds {
     
     /**
-     * The id_token is invalid.
+     * The access token is invalid.
      */
     @Nonnull @NotEmpty public static final String INVALID_ACCESS_TOKEN = "InvalidAcessToken";

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list